Logs class

Inheritance

Constructors

Logs({Key? key, required LogTheme theme, required LogStorage logStorage, Duration minActiveLogDuration = const Duration(milliseconds: 3000), Duration activeLogFadeDuration = const Duration(milliseconds: 500), Duration scrollToBottomDelay = const Duration(milliseconds: 200), Duration scrollToBottomDuration = const Duration(milliseconds: 1000), Duration fastScrollToBottomDuration = const Duration(milliseconds: 300), void onPaused()?, void onResumed()?, void onCleared()?, void onScrollStart(Log log)?, void onScrollEnd(Log log, Object? error, StackTrace? stackTrace)?, void onRemovedLogsCleared()?})
const

Properties

activeLogFadeDuration Duration
final
fastScrollToBottomDuration Duration
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
logStorage → LogStorage
final
minActiveLogDuration Duration
final
onCleared → void Function()?
final
onPaused → void Function()?
final
onRemovedLogsCleared → void Function()?
final
onResumed → void Function()?
final
onScrollEnd → void Function(Log log, Object? error, StackTrace? stackTrace)?
final
onScrollStart → void Function(Log log)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollToBottomDelay Duration
final
scrollToBottomDuration Duration
final
theme → LogTheme
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<Logs>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited